@@ -20,6 +20,9 @@
 import argparse
 import os
 import requests
+from requests.adapters import HTTPAdapter
+from requests.packages import urllib3
+from requests.packages.urllib3.util.retry import Retry
 import socket
 from urllib.parse import urlparse
 import xmlrpc.client
@@ -47,6 +50,23 @@ class RequestsTransport(xmlrpc.client.Transport):
     def __init__(self, scheme, proxy=None, timeout=20.0, verify_ssl_cert=True):
         super().__init__()
         self.scheme = scheme
+
+        # Create a session
+        self.session = requests.Session()
+        if urllib3.__version__ >= "1.26":
+            allowed_methods = "allowed_methods"
+        else:
+            allowed_methods = "method_whitelist"  # pragma: no cover
+        retry_strategy = Retry(
+            total=3,
+            status_forcelist=[413, 429, 500, 503, 504],
+            backoff_factor=1,
+            **{allowed_methods: ["HEAD", "OPTIONS", "GET", "POST"]},
+        )
+        adapter = HTTPAdapter(max_retries=retry_strategy)
+        self.session.mount("https://", adapter)
+        self.session.mount("http://", adapter)
+
         # Set the user agent
         self.user_agent = "lavacli v%s" % __version__
         if proxy is None:
@@ -69,7 +89,7 @@ class RequestsTransport(xmlrpc.client.Transport):
         url = "%s://%s%s" % (self.scheme, host, handler)
         try:
             response = None
-            response = requests.post(
+            response = self.session.post(
                 url,
                 data=request_body,
                 headers=headers,
