@@ -233,7 +233,7 @@ def handle_listen(proxy, options, config):
                     try:
                         async with aiohttp.ClientSession(headers=HEADERS) as session:
                             print("Connecting to %s" % ws_url)
-                            async with session.ws_connect(ws_url) as ws:
+                            async with session.ws_connect(ws_url, heartbeat=30) as ws:
                                 async for msg in ws:
                                     if msg.type == aiohttp.WSMsgType.TEXT:
                                         try:
