@@ -365,7 +365,7 @@ def handle_apply(proxy, options, config):
                     print_file_diff(template, dt.get_template(base))
                     if not options.dry_run:
                         proxy.scheduler.device_types.set_template(
-                            dt.name, dt.template(base)
+                            dt.name, dt.get_template(base)
                         )
 
     print(f"{colors.cyan}> workers{colors.reset}")
