@@ -20,7 +20,6 @@
 import json
 import sys
 import xmlrpc.client
-import yaml
 
 from lavacli import main
 
@@ -36,12 +35,7 @@ def test_results_job(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testjob_results_yaml",
                 "args": ("1234",),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "job", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"},{"suite": "lava", "name": "job", "result": "fail"}]""",
             },
         ],
     )
@@ -67,13 +61,7 @@ def test_results_job_isatty(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testjob_results_yaml",
                 "args": ("1234",),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "boot", "result": "skip"},
-                        {"suite": "lava", "name": "job", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"}, {"suite": "lava", "name": "boot", "result": "skip"}, {"suite": "lava", "name": "job", "result": "fail"}]""",
             },
         ],
     )
@@ -99,12 +87,7 @@ def test_results_job_json(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testjob_results_yaml",
                 "args": ("1234",),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "job", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"},{"suite": "lava", "name": "job", "result": "fail"}]""",
             },
         ],
     )
@@ -126,12 +109,7 @@ def test_results_job_yaml(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testjob_results_yaml",
                 "args": ("1234",),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "job", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"},{"suite": "lava", "name": "job", "result": "fail"}]""",
             },
         ],
     )
@@ -155,12 +133,7 @@ def test_results_suite(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testsuite_results_yaml",
                 "args": ("1234", "lava"),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "job", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"},{"suite": "lava", "name": "job", "result": "fail"}]""",
             },
         ],
     )
@@ -185,12 +158,7 @@ def test_results_suite_json(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testsuite_results_yaml",
                 "args": ("1234", "lava"),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "job", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"},{"suite": "lava", "name": "job", "result": "fail"}]""",
             },
         ],
     )
@@ -212,12 +180,7 @@ def test_results_suite_yaml(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testsuite_results_yaml",
                 "args": ("1234", "lava"),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "job", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"},{"suite": "lava", "name": "job", "result": "fail"}]""",
             },
         ],
     )
@@ -241,9 +204,7 @@ def test_results_case(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testcase_results_yaml",
                 "args": ("1234", "lava", "validate"),
-                "ret": yaml.dump(
-                    [{"suite": "lava", "name": "validate", "result": "pass"}]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"}]""",
             },
         ],
     )
@@ -263,9 +224,7 @@ def test_results_case_isatty_pass(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testcase_results_yaml",
                 "args": ("1234", "lava", "validate"),
-                "ret": yaml.dump(
-                    [{"suite": "lava", "name": "validate", "result": "pass"}]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"}]""",
             },
         ],
     )
@@ -285,9 +244,7 @@ def test_results_case_isatty_fail(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testcase_results_yaml",
                 "args": ("1234", "lava", "validate"),
-                "ret": yaml.dump(
-                    [{"suite": "lava", "name": "validate", "result": "fail"}]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "fail"}]""",
             },
         ],
     )
@@ -307,9 +264,7 @@ def test_results_case_isatty_skip(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testcase_results_yaml",
                 "args": ("1234", "lava", "validate"),
-                "ret": yaml.dump(
-                    [{"suite": "lava", "name": "validate", "result": "skip"}]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "skip"}]""",
             },
         ],
     )
@@ -328,12 +283,7 @@ def test_results_case_1(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testcase_results_yaml",
                 "args": ("1234", "lava", "validate"),
-                "ret": yaml.dump(
-                    [
-                        {"suite": "lava", "name": "validate", "result": "pass"},
-                        {"suite": "lava", "name": "validate", "result": "fail"},
-                    ]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"},{"suite": "lava", "name": "validate", "result": "fail"}]""",
             },
         ],
     )
@@ -354,9 +304,7 @@ def test_results_case_json(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testcase_results_yaml",
                 "args": ("1234", "lava", "validate"),
-                "ret": yaml.dump(
-                    [{"suite": "lava", "name": "validate", "result": "pass"}]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"}]""",
             },
         ],
     )
@@ -379,9 +327,7 @@ def test_results_case_yaml(setup, monkeypatch, capsys):
             {
                 "request": "results.get_testcase_results_yaml",
                 "args": ("1234", "lava", "validate"),
-                "ret": yaml.dump(
-                    [{"suite": "lava", "name": "validate", "result": "pass"}]
-                ),
+                "ret": """[{"suite": "lava", "name": "validate", "result": "pass"}]""",
             },
         ],
     )
