@@ -21,7 +21,6 @@ import json
 import sys
 import time
 import xmlrpc.client
-import yaml
 
 from lavacli import main
 
@@ -76,6 +75,35 @@ def test_workers_add_1(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == ""  # nosec
 
 
+def test_workers_config_delete(setup, monkeypatch, capsys, tmpdir):
+    version = "2022.4"
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        [
+            "lavacli",
+            "workers",
+            "config",
+            "delete",
+            "worker01",
+        ],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.set_config",
+                "args": ("worker01", ""),
+                "ret": True,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
 def test_workers_config_get(setup, monkeypatch, capsys):
     version = "2018.4"
     monkeypatch.setattr(
@@ -161,6 +189,29 @@ def test_workers_config_set_error(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "Unable to store worker configuration\n"  # nosec
 
 
+def test_workers_env_delete(setup, monkeypatch, capsys, tmpdir):
+    version = "2022.4"
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["lavacli", "workers", "env", "delete", "worker01"],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.set_env",
+                "args": ("worker01", ""),
+                "ret": True,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
 def test_workers_env_get(setup, monkeypatch, capsys):
     version = "2019.6"
     monkeypatch.setattr(sys, "argv", ["lavacli", "workers", "env", "get", "worker01"])
@@ -230,6 +281,100 @@ def test_workers_env_set_error(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "Unable to store worker environment\n"  # nosec
 
 
+def test_workers_env_dut_delete(setup, monkeypatch, capsys, tmpdir):
+    version = "2022.4"
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["lavacli", "workers", "env-dut", "delete", "worker01"],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.set_env_dut",
+                "args": ("worker01", ""),
+                "ret": True,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
+def test_workers_env_dut_get(setup, monkeypatch, capsys):
+    version = "2022.4"
+    monkeypatch.setattr(
+        sys, "argv", ["lavacli", "workers", "env-dut", "get", "worker01"]
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.get_env_dut",
+                "args": ("worker01",),
+                "ret": "env-dut content",
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == "env-dut content\n"  # nosec
+
+
+def test_workers_env_dut_set(setup, monkeypatch, capsys, tmpdir):
+    version = "2022.4"
+    with (tmpdir / "env.yaml").open("w") as f_conf:
+        f_conf.write("env-dut content")
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["lavacli", "workers", "env-dut", "set", "worker01", str(tmpdir / "env.yaml")],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.set_env_dut",
+                "args": ("worker01", "env-dut content"),
+                "ret": True,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
+def test_workers_env_dut_set_error(setup, monkeypatch, capsys, tmpdir):
+    version = "2022.4"
+    with (tmpdir / "env.yaml").open("w") as f_conf:
+        f_conf.write("env-dut content")
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["lavacli", "workers", "env-dut", "set", "worker01", str(tmpdir / "env.yaml")],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.set_env_dut",
+                "args": ("worker01", "env-dut content"),
+                "ret": False,
+            },
+        ],
+    )
+    assert main() == 1  # nosec
+    assert capsys.readouterr()[0] == "Unable to store worker dut environment\n"  # nosec
+
+
 def test_workers_list(setup, monkeypatch, capsys):
     version = "2018.4"
     monkeypatch.setattr(sys, "argv", ["lavacli", "workers", "list"])
